@@ -15,8 +15,7 @@ from rgov import utils
 
 class DaemonCommand(Command):
     name = "daemon"
-    descripti
-    on = "Start a daemon that checks for availability automatically"
+    description = "Start a daemon that checks for availability automatically"
 
     help = """The <question>daemon</> command starts a Unix daemon that checks for campground availability every five minutes. If one or more campground(s) are found to have available sites, a Pushsafer notification is sent with a summary of which campground(s) are currently available.
 
