@@ -1,6 +1,5 @@
 from cleo import Command
-from cleo.helpers import option, argument
-
+from cleo.helpers import argument, option
 from rgov import search
 
 
@@ -11,7 +10,7 @@ class SearchCommand(Command):
     arguments = [argument("terms", "The terms to search for", multiple=True)]
     options = [
         option("descriptions", "d", "Search descriptions"),
-        option("interactive", "i", "Interact with the search results")
+        option("interactive", "i", "Interact with the search results"),
     ]
 
     help = """The <question>search</> command searches a local database for campground id(s). By default, search arguments are matched with the name of the campground, but the <comment>descriptions</> option can be enabled to search for matching descriptions.
@@ -28,16 +27,16 @@ Search for the campground "North Rim Campground":
 
     $ <info>rgov search north rim</>
 """
-    
+
     def handle(self):
         search_terms = self.argument("terms")
-        
+
         if self.option("descriptions"):
             descriptions = True
         else:
-            descriptions = False 
-            
+            descriptions = False
+
         search_results = search.search(search_terms, descriptions)
 
         for name, id_num in search_results:
-            self.line(f"<info>{name}</> [<question>{id_num}</>]") 
+            self.line(f"<info>{name}</> [<question>{id_num}</>]")
